@@ -3,7 +3,7 @@ This module provides an easy access to the application settings
 """
 import json
 import os
-from pyqode.core.qt.QtCore import QSettings
+from pyqode.qt.QtCore import QSettings
 import sys
 
 
