@@ -52,7 +52,8 @@ class PythonFoldDetector(IndentFoldDetector):
         # Python is an indent based language so use indentation for folding
         # makes sense but we restrict new regions to indentation after a ':',
         # that way only the real logical blocks are displayed.
-        lvl = super().detect_fold_level(prev_block, block)
+        lvl = super(PythonFoldDetector, self).detect_fold_level(
+            prev_block, block)
         # cancel false indentation, indentation can only happen if there is
         # ':' on the previous line
         prev_lvl = TextBlockHelper.get_fold_lvl(prev_block)
